# **:- Change Log -:**

> **0.0.1** -- [ 11 APRIL 2023 ]  
> [ NOTICE ]  
> [ ! ] - Initial Release

> **0.0.2 - 0.0.5**  
> [ INFO ]  
> [+] Upload and Import Error

> **0.0.6** -- [ 11 APRIL 2023 ]  
> [ NOTICE ]  
> [+] Module Install fixed

> **0.0.7** -- [ 25 APRIL 2023 ]  
> [ ADDED ]  
> [+] Cursor change on titlebar drag  
> [+] Get window detailes  
> [+] Persistent styling  
> [+] Custom window widget spacing
> [+] Custom window margin
>
> [ FIXED ]  
> [+] Extra space between widgets  
> [+] Custom Titlebar  
> [+] Window glitch using "Titlebar" element, "add" > and "update" method
>
> [ REMOVED ]  
> [+] Clera default titlebar style

> **0.0.8** -- [ 04 JULY 2023 ]  
> [ ADDED ]  
> [+] Extra controls of Window  
> [+] Stack Element for multi page development  
> [+] Extraction, Styling and Linking of Textarea scrollbar  
> [+] Wordwrap for Textarea  
> [+] Popup Window lock
>
> [ FIXED ]  
> [+] Windows style control icon  
> [+] Fusion style control icon  
> [+] File Element filter definition error
>
> [ CHANGED ]  
> [+] Default window spacing and content margin  
> [+] Stylesheet linking extension. Now only useds ".cx" extension

> **0.1.0** -- [ 11 JULY 2023 ]  
> [ ADDED ]  
> [+] Quick argument values  
> [+] Clera Style Editor
>
> [ CHANGED ]  
> [+] sizepolicy declaration
>
> [ FIXED ]  
> [+] ModuleNotFoundError: No module named 'clera.stubs'  
> [+] Window icon display  
> [+] AttributeError: 'MainWindow' object has no attribute 'old_position'

> **0.1.1** -- [ 11 JULY 2023 ]  
> [ NOTICE ]  
> [+] Minor Fixes

> **0.1.2** -- [ - ]  
> [ ADDED ]  
> [+] Minor Fixes

> **0.2.0** -- [ 08 AUGUST 2023 ]  
> [ ADDED ]  
> [+] Database  
> [+] Color Popup  
> [+] More editor Features
>
> [ FIXED ]  
> [+] Highlight error  
> [+] Editor Error and function call

**v0.2.1 (2023-08-15) - Various fixes and additions**

- Library Download Incompatibility (**fixed**)
- Base64 Image format load (**added**)


**v0.2.2 (2023-12-19) - Various fixes and additions**

- Custom Titlebar Control Buttons (**fixed**)
- Clera Deploy (Covert Code to Executable) (**added**)
- Hover Parameter for Button (**added**)
- Multiprocessor (**added**)
- Clera Editor Not Running (**fixed**)
- "database" not in module (**fixed**)


**v0.2.3 (2024-06-11) - Various fixes and additions**

- Shortcut button errors (**fixed**)    
- Stack widget extra padding (**fixed**)    
- Dynamic window resize through code (**added**)    
- Group layout strict policy (**fixed**)    
- Checked method to GET (**added**) 

<br>

- Get screen size feature (**added**)   
- Screenshot feature (**added**)    
- Hide taskbar icon (**added**) 

<br>

- Persistent hide mouse pointer (**added**) 
- Windows titlebar control buttons appearance (**upgraded**)    

<br>

- .close() method to Window() [same as .quit()] (**added**)     

<br>

- Center, move, fixed size feature to popup (**added**) 

<br>

- Margin and spacing feature to popup (**added**)   
- Double click gesture to titlebar element (**added**)  

<br>

- Popup messing up after deployment (**fixed**)  

<br>


**v0.2.4 (2025-01-07) - Various fixes and additions**

- Table widget with td element (**added**)    
- Shortcut element (**added**)  

<br>
  
- Cursor overide (**fixed**)    
- Clera-editor not running (**fixed**)    
- Top functionality to Window()._move() method (**added**)      

<br>

- Style method to window element (**added**)   
- Toggle view for toolbar (**added**)    

<br>

- Parse arguments and keyword arguments to functions through thread (**added**)   

<br>


**v0.2.5 (2025-02-18) - Various fixes and additions**

- Docstrings and Documentation (**added**)    
- Optimized for faster code execution (**fixed**)     

<br>


**v0.2.5 (2025-02-18) - Various fixes and additions**

- Docstrings and Documentation (**added**)    
- Optimized for faster code execution (**fixed**)     

<br>
